@@ -1,6 +1,4 @@
 """ Use case queries for the kospex DB"""
-from ctypes import memmove
-from logging import lastResort
 import time
 import re
 from typing import Optional
@@ -278,6 +276,23 @@ class KospexQuery:
 
         return results
 
+    def get_email_maps(self, alias=None, email=None):
+        """
+        Get the email maps for the given scope.
+        If no parameters are passed, return all email maps.
+        """
+        kd = KospexData(self.kospex_db)
+        kd.from_table(KospexSchema.TBL_EMAIL_MAP)
+
+        if alias:
+            kd.where("alias_email","=",alias)
+
+        if email:
+            kd.where("main_email","=",email)
+
+        results = kd.execute()
+
+        return results
 
 
     def get_orphans(self,id=None):
@@ -953,14 +968,23 @@ class KospexQuery:
 
         return results
 
-    def email_domains(self, repo_id=None):
+    def email_domains(self, repo_id=None, days=None):
         """ Provide a summary of email domains for repositories."""
         where_clause = ""
         params = []
+
         if repo_id:
             where_clause = " WHERE _repo_id = ? "
             params.append(repo_id)
 
+        if days:
+            from_date = KospexUtils.days_ago_iso_date(days)
+            params.append(from_date)
+            if repo_id:
+                where_clause += " AND committer_when >= ?"
+            else:
+                where_clause += " Where committer_when >= ?"
+
         summary_sql = f"""SELECT substr(author_email, instr(author_email, '@') + 1) as domain,
         COUNT(DISTINCT author_email) 'addresses'
         FROM commits
@@ -1311,6 +1335,19 @@ class KospexQuery:
 
         return summary
 
+    def get_last_sync_datetime(self):
+        """
+        Return the last sync datetime of the most recent repo sync
+        Used to determine if data should be updated
+        """
+
+        sql = f"""SELECT * FROM {KospexSchema.TBL_REPOS} ORDER BY last_sync DESC LIMIT 1"""
+        data = self.kospex_db.query(sql,[])
+        record = next(data, None)
+        if record:
+            return record['last_sync']
+        return None
+
 
     def get_file_authors(self, file_name=None, repo_id=None):
         """
@@ -1339,7 +1376,7 @@ class KospexQuery:
 
         return results
 
-    def developer_tech(self, author_email=None, repo_id=None, developers=None):
+    def developer_tech(self, author_email=None, repo_id=None, developers=None, year=None):
         """
         Return the tech stack for an author or repo
         This function is part of
@@ -1352,6 +1389,8 @@ class KospexQuery:
         kd = KospexData(self.kospex_db)
         kd.from_table("commit_files", "commits")
 
+
+
         #kd.select_raw("DISTINCT(LOWER(author_email)) as author_email")
         kd.select_raw("LOWER(author_email) as author_email")
         #kd.select_as("DISTINCT(author_email)", "author_email")
@@ -1383,6 +1422,16 @@ class KospexQuery:
             params.append(repo_id)
             kd.where("commits._repo_id", "=", repo_id)
 
+        if year:
+            start_date = datetime(year, 1, 1)
+            start_iso = start_date.isoformat()  # "2023-01-01T00:00
+            print(f"Start date: {start_iso}")
+            end_date = datetime(year, 12, 31, 23, 59, 59)
+            end_iso = end_date.isoformat()  # "2023-01-01T00:00
+            print(f"End date: {end_iso}")
+            kd.where("commits.committer_when", ">=", start_iso)
+            kd.where("commits.committer_when", "<=", end_iso)
+
         # We're going to need a few lookups
         # Potentially we could do this in a nasty join, but it's easier to read this way
 
