@@ -1,6 +1,9 @@
 """ Tests for Kospex Utils """
+from pathlib import Path
 import kospex_utils as KospexUtils
 
+HERE = Path(__file__).parent
+
 # Tests
 
 def test_developer_tenure():
@@ -11,3 +14,11 @@ def test_developer_tenure():
     assert "< 3 months" == KospexUtils.get_status(15)
 
     assert KospexUtils.DEFAULT_MAX_STATUS == KospexUtils.get_status(731)
+
+def test_mailmap():
+    """
+    Test mailmap parsing
+    """
+
+    results = KospexUtils.parse_mailmap(f"{HERE}/mailmap/github.com/adamtornhill/code-maat/.mailmap")
+    print(results)
